package org.dive4elements.river.client.shared.model;

import java.util.Map;


public class MultiAttributeData
implements Data
{

    public static final String TYPE = "multiattribute";

    protected String label;
    protected String description;

    protected Map<String, Map<String, String>> meta;

    public DataItem[] opts;


    public MultiAttributeData() {
    }


    public MultiAttributeData(
        String                           label,
        String                           desc,
        DataItem[]                       opts,
        Map<String, Map<String, String>> meta
    ) {
        this.label       = label;
        this.description = desc;
        this.opts        = opts;
    }

    public Map<String, Map<String, String>> getMeta() {
        return meta;
    }

    /**
     * Returns the label of the item.
     *
     * @return the label.
     */
    public String getLabel() {
        return label;
    }


    /**
     * Returns the description of the item.
     *
     * @return the description.
     */
    public String getDescription() {
        return description;
    }


    /**
     * Returns the type of the item.
     *
     * @return the type.
     */
    public String getType() {
        return TYPE;
    }


    /**
     * Returns the data items which represent the allowed options for this Data.
     *
     * @return the allowed options as DataItem array.
     */
    public DataItem[] getItems() {
        return opts;
    }


    /**
     * @return always null.
     */
    public DataItem getDefault() {
        return null;
    }


    /**
     * Returns the values as colon separated string.
     *
     * @return colon separated string.
     */
    public String getStringValue() {
        String data = "";
        boolean first = true;
        for (int i = 0; i < opts.length; i++) {
            if (!first) {
                data += ";";
            }
            data += opts[i].getStringValue();
            first = false;
        }
        return data;
    }
}
